#!/bin/bash
#
# Copyright (C) 2004-2011 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR
#
# This file is part of le-interface
#
# le-interface is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
# USA.

# Files
EXTRAS="applications-extras.menu"
ADMIN="applications-admin.menu"
EDIT="applications-edit.menu"

# Paths
MENUPATH="$HOME/.config/menus"
LEMENUPATH="/etc/xdg/menus/le-menu"
WINEAPPATH="$HOME/.local/share/applications/wine"
TOTEMICONPATH="/usr/share/applications/totem.desktop"

# Remove totem's icon from the menu
if test -e $TOTEMICONPATH; then
    rm $TOTEMICONPATH
fi

# Verify existence of menu configuration directory
if test ! -d "$MENUPATH/"; then
    mkdir -p "$MENUPATH"
    chown -R --reference="$HOME" "$HOME/.config"
fi

# Change menu according to user groups
# For admin users, show admin menu and enable menu item edition
if groups $USER | grep -q "\<admin\>"; then
    cp "$LEMENUPATH/$EDIT" "$MENUPATH/"
    if test ! -f "$MENUPATH/$ADMIN"; then
        cp "$LEMENUPATH/$ADMIN" "$MENUPATH/"
    fi
else
    # Restore default menu for non-admin and freeze users
    if groups $USER | grep -q "\<freeze\>"; then
        rm -f "$MENUPATH/"* &> /dev/null
    else
        # Allow non-freeze users do edit menu
        cp "$LEMENUPATH/$EDIT" "$MENUPATH/"
    fi
fi

# Create a list with wine files
WINEDKTP=$(find $WINEAPPATH -name "*.desktop" | tr ' ' '@')

FILELIST=""
for deskfile in $WINEDKTP; do
	filename=$(echo $deskfile | cut -d'/' --complement -f1,2,3,4,5,6)
	filename=$(echo $filename | tr "@" ' ' | tr "/" "-")
	FILELIST="$FILELIST <Filename>$filename</Filename>"
done

# Copy extras menu model and modify it
cp "$LEMENUPATH/$EXTRAS" "$MENUPATH/"
sed -i "s:@:$FILELIST:" "$MENUPATH/$EXTRAS"

# Change files owner based on home directory
chown -R --reference="$HOME" "$MENUPATH"
