#!/bin/bash
#
# Copyright (C) 2004-2011 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR
#
# This file is part of le-interface
#
# le-interface is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
# USA.

SKELFILE="/etc/skel/.kde/share/config/plasma-desktop-appletsrc"
CONFFILE="${HOME}/.kde/share/config/plasma-desktop-appletsrc"
AUTOSTARTFOLDER="${HOME}/.kde/Autostart"

# If the le-multiterminal isn't installed, enable network-manager-gnome for
# all users. Otherwise, enable knetworkmanager only for the teacher user.
if test $(dpkg -l le-multiterminal | grep -c '^ii') -eq 0; then
    # If there is no Autostart folder, create it
    if ! test -d ${AUTOSTARTFOLDER}; then
        mkdir -p ${AUTOSTARTFOLDER}
    fi

    # Link the network-manager-gnome applet to the user's Autostart folder
    if ! test -h ${AUTOSTARTFOLDER}/nm-applet-link; then
        ln -s /usr/bin/nm-applet ${AUTOSTARTFOLDER}/nm-applet-link
    fi

    exit 0
fi

# If user is a student, exit
if id ${USER} | grep -q "(\<aluno\>)" 2>/dev/null ; then
    exit 0
fi

# If there is no conffile, copy it from skel
if ! test -f ${CONFFILE}; then
    cp ${SKELFILE} ${CONFFILE}
fi

PLUGIN=$(grep "^plugin=networkmanagement$" $CONFFILE)

# If network management is already configured, exit
if test -n "$PLUGIN"; then
    exit 0
fi

IDS1="^\[Containments\]\[[0-9]*\]\[Applets\]\[[0-9]*\]"
IDS2="\[Configuration\]\[Applets\]\[[0-9]*\]$"
ID=$(egrep "${IDS1}${IDS2}" ${CONFFILE} | \
     cut -d "[" -f8 | sed 's/\]//g' | sort -g | tail -n1)

ID=$(( ${ID} + 1 ))

SYSTRAYID=$(grep 'plugin=systemtray' -B10 ${CONFFILE} | \
            egrep '^\[Containments\]\[[0-9]*\]\[Applets\]\[[0-9]*\]$' | \
            tail -n1 | cut -d'[' -f5 | cut -d']' -f1)

kwriteconfig --file ${CONFFILE} --group Containments --group 2 --group Applets \
             --group ${SYSTRAYID} --group Configuration --group Applets \
             --group ${ID} --key immutability "1"

kwriteconfig --file ${CONFFILE} --group Containments --group 2 --group Applets \
             --group ${SYSTRAYID} --group Configuration --group Applets \
             --group ${ID} --key plugin "networkmanagement"

kwriteconfig --file ${CONFFILE} --group Containments --group 2 --group Applets \
             --group ${SYSTRAYID} --group Configuration --group Applets \
             --group ${ID} --key zvalue "0"

chown -R --reference="$HOME" "$HOME/.kde"
